@@ -1,4 +1,4 @@
-.onLoad <- function(libname, pkgname)
+.onAttach <- function(libname, pkgname)
   {
     options(bigmemory.typecast.warning=FALSE)
      options(bigmemory.allow.dimnames=TRUE)
